===============================
Lambda-invoke
===============================


.. image:: https://img.shields.io/pypi/v/lambda-requests.svg
        :target: https://pypi.python.org/pypi/lambda-invoke


Lambda-invoke a convenient library for calling AWS lambdas using proxy
interface 

Quick start
------------

Installation
````````````

.. code-block:: shell

    pip intall lambda-invoke

Examples
````````

For usage examples refer to lambda-request or lambda-httpx.
